unit Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls, SchmCntr;

type
  TfrmMain = class(TForm)
    SchemaDesignArea1: TSchemaDesignArea;
    pnlButtons: TPanel;
    btnAddTree: TButton;
    btnAddListbox: TButton;
    btnAddCheckListbox: TButton;
    btnAddText: TButton;
    btnAddIcon: TButton;
    Button9: TButton;
    Button10: TButton;
    Image1: TImage;
    Image2: TImage;
    Image3: TImage;
    ImageList1: TImageList;
    btnAddLinks: TButton;
    chkShowSysToolbar: TCheckBox;
    lblHomepage: TLabel;
    procedure btnAddTreeClick(Sender: TObject);
    procedure btnAddListboxClick(Sender: TObject);
    procedure btnAddCheckListboxClick(Sender: TObject);
    procedure btnAddTextClick(Sender: TObject);
    procedure btnAddIconClick(Sender: TObject);
    procedure Button9Click(Sender: TObject);
    procedure Button10Click(Sender: TObject);
    procedure btnAddLinksClick(Sender: TObject);
    procedure chkShowSysToolbarClick(Sender: TObject);
    procedure lblHomepageClick(Sender: TObject);
  private
    { Private declarations }
    procedure AddItem(AControlType: TSchemaControlType);
  public
    { Public declarations }
  end;

var
  frmMain: TfrmMain;

implementation

{$R *.DFM}
{$R winxp.res}
uses ShellAPI;

procedure TfrmMain.AddItem(AControlType: TSchemaControlType);
var
  i: Integer;
begin
  with SchemaDesignArea1.AddItem('New item' + IntToStr(Random(100)), AControlType) do
  begin
    Left := Random(100);
    Top := Random(100);
    Hint := 'hint for ' + Caption;
    case Random(2) of
      0: Icon := image1.Picture.Icon;
      1: Icon := image2.Picture.Icon;
    else
      Icon := image3.Picture.Icon;
    end;

    for i := 1 to Random(10)+1 do
      AddSubItem('New sub-item' + IntToStr(i), Random(i)-1, False);
    RecalculateHeight;
    RecalculateWidth;
  end;
end;

procedure TfrmMain.btnAddTreeClick(Sender: TObject);
begin
  AddItem(scTreeView)
end;

procedure TfrmMain.btnAddListboxClick(Sender: TObject);
begin
  AddItem(scListbox)
end;

procedure TfrmMain.btnAddCheckListboxClick(Sender: TObject);
begin
  AddItem(scCheckListbox)
end;

procedure TfrmMain.btnAddTextClick(Sender: TObject);
var
  si: TSchemaItem;
begin
  si := SchemaDesignArea1.AddItem('New text' + IntToStr(Random(100)), scText);
  si.Left := Random(100);
  si.Top := Random(100);
  si.Height := 100;
  si.Caption := 'First line'#13#10'Second line';
  si.Color := clInfoBk;
  si.Font.Style := [fsBold];
  if (si.ItemControl is TSchemaText) then
    with TSchemaText(si.ItemControl) do
      Alignment := taCenter;

  case Random(2) of
    0: si.Icon := image1.Picture.Icon;
    1: si.Icon := image2.Picture.Icon;
  else
    si.Icon := image3.Picture.Icon;
  end;

  si.RecalculateHeight;
  si.RecalculateWidth;
end;


procedure TfrmMain.btnAddIconClick(Sender: TObject);
var
  si: TSchemaItem;
begin
  si := SchemaDesignArea1.AddItem('New text' + IntToStr(Random(100)), scIcon);
  with si do
  begin
    Left := Random(100);
    Top := Random(100);
    Height := 100;
    if (ItemControl is TSchemaIcon) then
      with TSchemaIcon(ItemControl) do
      begin
        IconType := TSCIconType(Random(Ord(High(TSCIconType))));
        Color := clInfoBk;
      end;

    RecalculateHeight;
    RecalculateWidth;
  end
end;

procedure TfrmMain.Button9Click(Sender: TObject);
begin
  SchemaDesignArea1.SaveToFile(ExtractFilePath(Application.ExeName) + 'block.scm');
end;

procedure TfrmMain.Button10Click(Sender: TObject);
begin
  SchemaDesignArea1.LoadFromFile(ExtractFilePath(Application.ExeName) + 'block.scm');
end;

procedure TfrmMain.btnAddLinksClick(Sender: TObject);
var
  i, intCount, intSubCount: Integer;
  si1, si2: TSchemaItem;
  ssi1, ssi2: TSchemaSubItem;
begin
  intCount := SchemaDesignArea1.GetItemCount-1;
  if intCount < 1 then
    raise Exception.Create('Create any items before.');

  for i := 0 to Random(5) do
  begin
    si1 := SchemaDesignArea1.GetItem(Random(intCount));
    ssi1 := nil;
    si2 := SchemaDesignArea1.GetItem(Random(intCount));
    ssi2 := nil;

    if Assigned(si1) then
    begin
      intSubCount := si1.GetSubItemCount-1;
      if (intSubCount > 0) then
        ssi1 := si1.GetSubItem(intSubCount);
    end;
    if Assigned(si2) then
    begin
      intSubCount := si2.GetSubItemCount-1;
      if (intSubCount > 0) then
        ssi2 := si2.GetSubItem(intSubCount);
    end;

    if (ssi1 <> ssi2) and (ssi1 <> nil) and (ssi2 <> nil) then
    begin
      try
        SchemaDesignArea1.AddRelation(si1, si2, ssi1, ssi2)
      except
      end
    end
  end;
end;

procedure TfrmMain.chkShowSysToolbarClick(Sender: TObject);
begin
  SchemaDesignArea1.ShowItemToolbar := chkShowSysToolbar.Checked
end;

procedure TfrmMain.lblHomepageClick(Sender: TObject);
begin
  ShellExecute(0, 'open', PChar((Sender as TLabel).Caption), nil, nil, SW_SHOWNORMAL);
end;

initialization
  Randomize;

end.
